using System;
using System.Collections.Generic;
using System.Text;

namespace Eve.Data
{
    public class InstallationType : EveProperty
    {
        private int assemblyLineTypeId;
        private int uiGroupingId;
        private int quantity;
        private double costInstall;
        private double costPerHour;
        private int restrictionMask;
        private double discountPerGoodStandingPoint;
        private double surchargePerBadStandingPoint;
        private double minimumStanding;
        private double minimumCharSecurity;
        private double minimumCorpSecurity;
        private double maximumCharSecurity;
        private double maximumCorpSecurity;

        private AssemblyLineType assemblyLineType;

        public AssemblyLineType AssemblyLineType
        {
            get
            {
                if (assemblyLineType == null)
                    assemblyLineType = new AssemblyLineType(db, assemblyLineTypeId);
                return assemblyLineType;
            }
        }
        public int Quantity
        {
            get { return quantity; }
        }
        public int UIGrouping
        {
            get { return uiGroupingId; }
        }
        public double InstallCost
        {
            get { return costInstall; }
        }
        public double CostPerHour
        {
            get { return costPerHour; }
        }
        public int RestrictionMask
        {
            get { return restrictionMask; }
        }
        public double GoodStandingDiscount
        {
            get { return discountPerGoodStandingPoint; }
        }
        public double BadStandingSurcharge
        {
            get { return surchargePerBadStandingPoint; }
        }
        public double MinimumStanding
        {
            get { return minimumStanding; }
        }
        public double MinimumCharacterSecurity
        {
            get { return minimumCharSecurity; }
        }
        public double MinimumCorporationSecurity
        {
            get { return minimumCorpSecurity; }
        }
        public double MaximumCharacterSecurity
        {
            get { return maximumCharSecurity; }
        }
        public double MaximumCorporationSecurity
        {
            get { return maximumCorpSecurity; }
        }

        internal InstallationType(DbDataRow dr)
            : base(dr.Database, EvePropertyType.InstallationType, dr["installationTypeID"])
        {
            Fill(dr);
        }
        internal InstallationType(Database db, int id)
            : base(db, EvePropertyType.InstallationType, id)
        {
            Fill(db.ExecuteSingle("SELECT * FROM ramInstallationTypeDefaultContents WHERE installationTypeID=" + id));
        }

        private void Fill(DbDataRow dr)
        {
            assemblyLineTypeId = dr["assemblyLineTypeID"];
            uiGroupingId = dr["UIGroupingID"];
            quantity = dr["quantity"];
            costInstall = dr["costInstall"];
            costPerHour = dr["costPerHour"];
            restrictionMask = dr["restrictionMask"];
            discountPerGoodStandingPoint = dr["discountPerGoodStandingPoint"];
            surchargePerBadStandingPoint = dr["surchargePerBadStandingPoint"];
            minimumStanding = dr["minimumStanding"];
            minimumCharSecurity = dr["minimumCharSecurity"];
            minimumCorpSecurity = dr["minimumCorpSecurity"];
            maximumCharSecurity = dr["maximumCharSecurity"];
            maximumCorpSecurity = dr["maximumCorpSecurity"];
        }
    }
}
