using System;
using System.Collections.Generic;
using System.Text;

namespace Eve.Data
{
    public class Region : EveObject
    {
        private string regionName;
        private double x, y, z;
        private double xMax, yMax, zMax;
        private double xMin, yMin, zMin;
        private int factionId;
        private double radius;

        private Faction faction = null;
        private Vector location;
        private Vector minimum;
        private Vector maximum;
        private List<Region> jumps;

        public string Name 
        { 
            get { return regionName; } 
        }
        public Vector Location
        {
            get
            {
                if (location == null)
                    location = new Vector(x, y, z);
                return location;
            }
        }
        public Vector Minimum
        {
            get
            {
                if (minimum == null)
                    minimum = new Vector(xMin, yMin, zMin);
                return minimum;
            }
        }
        public Vector Maximum
        {
            get
            {
                if (maximum == null)
                    maximum = new Vector(xMax, yMax, zMax);
                return maximum;
            }
        }
        public double Radius
        {
            get { return radius; }
        }
        public Faction Faction
        {
            get
            {
                if (faction == null)
                    faction = new Faction(db, factionId);
                return faction;
            }
        }
        public List<Region> Jumps
        {
            get
            {
                if (jumps == null)
                {
                    jumps = new List<Region>();
                    string query = "SELECT * FROM mapRegionJumps WHERE fromRegionID=" + Id;
                    foreach (DbDataRow row in db.ExecuteQuery(query))
                        jumps.Add(new Region(row));
                }
                return jumps;
            }
        }

        internal Region(DbDataRow dr)
            : base(dr.Database, EveObjectType.Region, dr["regionID"])
        {
            Fill(dr);
        }
        internal Region(Database db, int id)
            : base(db, EveObjectType.Region, id)
        {
            Fill(db.ExecuteSingle("SELECT * FROM mapRegions WHERE regionID=" + id));
        }

        private void Fill(DbDataRow dr)
        {
            regionName = dr["regionName"];
            x = dr["x"];
            y = dr["y"];
            z = dr["z"];
            xMin = dr["xMin"];
            yMin = dr["yMin"];
            zMin = dr["zMin"];
            xMax = dr["xMax"];
            yMax = dr["yMax"];
            zMax = dr["zMax"];
            factionId = dr["factionID"];
            radius = dr["radius"];
        }
    }
}
